@@ -3,9 +3,7 @@ package Devel::hdb::Router;
 use strict;
 use warnings;
 
-our $VERSION = '0.23_14';
-
-use Devel::hdb::Logger qw(log);
+our $VERSION = '0.23_15';
 
 sub new {
     my $class = shift;
@@ -18,7 +16,7 @@ foreach my $method ( qw(get post put delete head) ) {
         sub {
             my(\$self, \$path, \$sub) = \@_;
             my \$list = \$self->{$key} ||= [];
-            #log("Registering route for \$key \$path");
+            #print STDERR "Registering route for \$key \$path\\n";
             push \@\$list, [ \$path, \$sub ];
         };
     );
@@ -32,7 +30,7 @@ sub route($$) {
     my $env = shift;
 
     my $req_method = $env->{REQUEST_METHOD};
-    log "Incoming request: $req_method ",$env->{PATH_INFO};
+    print STDERR "Incoming request: $req_method ",$env->{PATH_INFO},"\n" if ($ENV{HDB_DEBUG_MSG});
     return unless exists $self->{$req_method};
     my $matchlist = $self->{$req_method};
 
@@ -51,17 +49,16 @@ sub route($$) {
         }
 
         if ($fire) {
-            log '  matched!';
+            print STDERR "  matched!\n" if ($ENV{HDB_DEBUG_MSG});
             my $rv = $cb->($env, @matches);
             my $hooks = $self->{after_hooks}->{$req_method}->{$path};
             if ($hooks && @$hooks) {
                 $_->($rv, $env, @matches) foreach @$hooks;
             }
-            log '  returning code ',$rv;
             return $rv;
         }
     }
-    log '  no matching route';
+    print STDERR "  no matching route\n" if ($ENV{HDB_DEBUG_MSG});
     return [ 404, [ 'Content-Type' => 'text/html'], ['Not found']];
 }
 
